package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````D!X```````!``````````&BU````
M`````````$``.``(`$``'0`<``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````7`````````!<``````````0`````````!````
M!0```````````````````````````````````,R>````````S)X`````````
M`"````````$````&````N*T```````"XK2```````+BM(```````L`0`````
M```0!0``````````(````````@````8```#@K0```````."M(```````X*T@
M``````#``0```````,`!````````"``````````$````!````!@"````````
M&`(````````8`@```````"P`````````+``````````$`````````%#E=&0$
M````+)<````````LEP```````"R7````````%`$````````4`0````````0`
M````````4N5T9`0```"XK0```````+BM(```````N*T@``````!(`@``````
M`$@"`````````0`````````O=7-R+VQI8F5X96,O;&0N96QF7W-O```'````
M!`````$```!.971"4T0``,"OTC4$````!`````,```!085@```````````!A
M````9```````````````,0```!L```````````````<```!.`````@``````
M``!"`````````#X````0````2``````````S````!0```!8```!'````4@``
M``L```!+````"0```!P`````````%0```%P```!`````30`````````P````
M8@```&,````:````10```$P```!$````6P```!X`````````"@```#P```!#
M````,@```"$```!9`````````#L````T`````````"T````X````6@```"0`
M```H````8````%$```!>`````````%<`````````5@```"H````.````````
M````````````4````"L`````````)@```%\````V`````````#T`````````
M-P```&$`````````4P```!D````4`````````%0`````````````````````
M````00````````!8````+P```#4`````````70``````````````````````
M``````````````$`````````````````````````````````````````````
M```````````````````````$``````````P`````````````````````````
M````````````````````````````````$0``````````````````````````
M````$P`````````C```````````````#````````````````````*0``````
M```/`````````"4`````````+``````````````````````````(````&```
M````````````````````````````)P``````````````%P```"(`````````
M`````#\````=````$@`````````````````````````````````````````&
M`````````$8```!/````2@```````````````````"```````````````#D`
M``!)````.@```%4`````````#0```!\````N````````````````````````
M`````````````````&<#```2``P`GE0````````%`@```````,<!```2````
M`````````````````````,0````1`````````````````````````+D!```2
M`````````````````````````&X````2``````````````````````````P`
M```2`````````````````````````'H!```2````````````````````````
M`&P#```2``P`N2\````````A`````````&X"```2````````````````````
M`````"L"```2`````````````````````````(\````0``T`L%8`````````
M`````````!H"```2`````````````````````````(8!```2````````````
M`````````````,\!```@`````````````````````````(8"```2````````
M`````````````````#("```2`````````````````````````+L"```2````
M``````````````````````L#```1`!<`^+$@```````(`````````.H"```2
M`````````````````````````.<!```2`````````````````````````'0`
M```2`````````````````````````(<#```2``P`LRD````````#````````
M`)4````2`````````````````````````"\!```2````````````````````
M`````!0````2`````````````````````````%H"```@````````````````
M`````````#\````2`````````````````````````!8#```1`!@`@+(@````
M```(`````````$<````2``````````````````````````\"```2````````
M`````````````````)@#```2``P`VB\```````"W`````````/T````2````
M`````````````````````*H#```2``P`D3````````"A!@```````"0$```0
M``D`D!H``````````````````/D"```2`````````````````````````(P"
M```2`````````````````````````",#```2````````````````````````
M`#$````2`````````````````````````$`"```2````````````````````
M`````+<#```2``P`/BD````````U`````````-\````6````````````````
M`````````/(````2`````````````````````````$@!```2````````````
M`````````````+\#```2``P`D!X``````````````````#@````2````````
M`````````````````-$````2`````````````````````````,<#```2``P`
MC"T```````!4`````````-4#```2``P`,C<````````Z`@```````.L#```2
M``P`#%````````"W`0```````/8#```1`!<`8+(@```````(`````````*4`
M```2`````````````````````````,`#```2``P`D!X`````````````````
M`+8"```1``````````````````````````8!```1`!@`P+(@```````(````
M```````$```2``P`M2L````````@``````````X!```2````````````````
M`````````#8!```1`````````````````````````&L!```2````````````
M`````````````!P````B`````````````````````````/D!```@````````
M`````````````````#`#```2`````````````````````````#\#```2````
M`````````````````````$$"```2`````````````````````````'T"```2
M``````````````````````````T$```0`!@`:+(@`````````````````",!
M```2`````````````````````````&8!```2````````````````````````
M`%\````2`````````````````````````!D$```2``P`X"T```````"U````
M`````"L````2`````````````````````````$\````2````````````````
M`````````"$$```2``P`N$\```````!4`````````$D"```2````````````
M`````````````"H$```2``P`U2L````````X`````````/,!```2````````
M`````````````````#8$```2``P`#2P```````!_`0```````*<"```2````
M`````````````````````#T#```2`````````````````````````%@!```2
M`````````````````````````(H````2`````````````````````````#D"
M```2`````````````````````````$,$```0`!<`:+(@````````````````
M`$H$```2``P`MBD```````#_`0```````*8!```2````````````````````
M`````%<$```2``P`PU$```````#;`@```````'L````2````````````````
M`````````$0#```2`````````````````````````)L!```2````````````
M`````````````$\#```2`````````````````````````%8#```2````````
M`````````````````)$"```2`````````````````````````&(#```0`!@`
MR+(@`````````````````)X````2`````````````````````````(4````2
M`````````````````````````*`"```2`````````````````````````+,`
M```2`````````````````````````&$$```2``P`;#D```````!.````````
M`)D"```2`````````````````````````!<!```2````````````````````
M``````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA;&EZ
M90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T870U
M,`!P97)L7V9R964`7V9I;FD`7U]S=&%T-3``;65M8W!Y`'!E<FQ?9&5S=')U
M8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S971P
M=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E;G9I
M<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`%!E<FQ?<V%F97-Y<VUA;&QO8P!?
M7W-T86-K7V-H:U]G=6%R9`!097)L7V=V7V9E=&-H<'8`7U]S<')I;G1F7V-H
M:P!R96%D`%!E<FQ?<WES7VEN:70S`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?;F5W6%,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<WES7W1E<FT`7U]E<G)N;P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!097)L
M7VUG7W-E=`!M:V1I<@!?7W)E9VES=&5R7V9R86UE7VEN9F\`<&5R;%]P87)S
M90!097)L7VYE=UA37V9L86=S`&%C8V5S<P!G971P:60`;65M8VAR`'9F<')I
M;G1F`%!E<FQ?871F;W)K7VQO8VL`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L
M7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P<FEN=&8`9V5T=6ED
M`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M<`!L:6)M+G-O+C``
M;&EB8W)Y<'0N<V\N,0!L:6)P=&AR96%D+G-O+C$`<'1H<F5A9%]A=&9O<FL`
M<W1R9'5P`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S7W-T<FEN9W,`7U]G
M971P=W5I9#4P`%]?<W1P8W!Y7V-H:P!A=&5X:70`7VQI8F-?:6YI=`!S=')T
M;VL`7U]R96%D9&ER,S``7V5N9`!M86EN`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7VUK=&UP9&ER`'AS7VEN:70`7U]S=&%R=`!P87)?96YV7V-L96%N`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S
M96YA;64`7U]B<W-?<W1A<G0`<&%R7V1I90!S:&%?:6YI=`!P87)?9&ER;F%M
M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD<')O9P!S:&%?9FEN86P`
M<&%R7V-L96%N=7``+W5S<B]P:V<O;&EB+W!E<FPU+S4N,S@N,"]X.#9?-C0M
M;F5T8G-D+71H<F5A9"UM=6QT:2]#3U)%.B]U<W(O<&MG+VQI8@``````L*\@
M```````(`````````."M(```````^+$@```````(`````````(BR(```````
M`+(@```````(``````````"R(```````8+(@```````(`````````*A9````
M````H*\@```````&`````P``````````````J*\@```````&````#@``````
M````````N*\@```````&````&@``````````````P*\@```````2````*0``
M````````````R*\@```````&````-0``````````````T*\@```````&````
M.0``````````````V*\@```````&````.P``````````````X*\@```````&
M````/```````````````Z*\@```````&````1P``````````````\*\@````
M```&````20``````````````^*\@```````&````5```````````````&+`@
M```````'`````@``````````````(+`@```````'````!```````````````
M*+`@```````'````!0``````````````,+`@```````'````!@``````````
M````.+`@```````'````!P``````````````0+`@```````'````"0``````
M````````2+`@```````'````"@``````````````4+`@```````'````#```
M````````````6+`@```````'````#0``````````````8+`@```````'````
M#P``````````````:+`@```````'````$```````````````<+`@```````'
M````$0``````````````>+`@```````'````$P``````````````@+`@````
M```'````%```````````````B+`@```````'````%0``````````````D+`@
M```````'````%P``````````````F+`@```````'````&```````````````
MH+`@```````'````&0``````````````J+`@```````'````&P``````````
M````L+`@```````'````'0``````````````N+`@```````'````'@``````
M````````P+`@```````'````(```````````````R+`@```````'````(P``
M````````````T+`@```````'````)```````````````V+`@```````'````
M)0``````````````X+`@```````'````)@``````````````Z+`@```````'
M````)P``````````````\+`@```````'````*@``````````````^+`@````
M```'````*P```````````````+$@```````'````+0``````````````"+$@
M```````'````+@``````````````$+$@```````'````,P``````````````
M&+$@```````'````.```````````````(+$@```````'````.@``````````
M````*+$@```````'````/0``````````````,+$@```````'````/@``````
M````````.+$@```````'````/P``````````````0+$@```````'````0```
M````````````2+$@```````'````0@``````````````4+$@```````'````
M0P``````````````6+$@```````'````1```````````````8+$@```````'
M````1@``````````````:+$@```````'````2P``````````````<+$@````
M```'````30``````````````>+$@```````'````3@``````````````@+$@
M```````'````3P``````````````B+$@```````'````4```````````````
MD+$@```````'````40``````````````F+$@```````'````5@``````````
M````H+$@```````'````5P``````````````J+$@```````'````6```````
M````````L+$@```````'````60``````````````N+$@```````'````6@``
M````````````P+$@```````'````6P``````````````R+$@```````'````
M70``````````````T+$@```````'````7@``````````````V+$@```````'
M````7P``````````````X+$@```````'````8```````````````Z+$@````
M```'````8@``````````````\+$@```````'````8P``````````````````
M``````!(@^P(Z&('``!(@\0(PP``_S5BE2``_R5DE2``#Q]``/\E8I4@`&@`
M````Z>#_____)5J5(`!H`0```.G0_____R52E2``:`(```#IP/____\E2I4@
M`&@#````Z;#_____)4*5(`!H!````.F@_____R4ZE2``:`4```#ID/____\E
M,I4@`&@&````Z8#_____)2J5(`!H!P```.EP_____R4BE2``:`@```#I8/__
M__\E&I4@`&@)````Z5#_____)1*5(`!H"@```.E`_____R4*E2``:`L```#I
M,/____\E`I4@`&@,````Z2#_____)?J4(`!H#0```.D0_____R7RE"``:`X`
M``#I`/____\EZI0@`&@/````Z?#^____)>*4(`!H$````.G@_O___R7:E"``
M:!$```#IT/[___\ETI0@`&@2````Z<#^____)<J4(`!H$P```.FP_O___R7"
ME"``:!0```#IH/[___\ENI0@`&@5````Z9#^____);*4(`!H%@```.F`_O__
M_R6JE"``:!<```#I</[___\EHI0@`&@8````Z6#^____)9J4(`!H&0```.E0
M_O___R62E"``:!H```#I0/[___\EBI0@`&@;````Z3#^____)8*4(`!H'```
M`.D@_O___R5ZE"``:!T```#I$/[___\E<I0@`&@>````Z0#^____)6J4(`!H
M'P```.GP_?___R5BE"``:"````#IX/W___\E6I0@`&@A````Z=#]____)5*4
M(`!H(@```.G`_?___R5*E"``:",```#IL/W___\E0I0@`&@D````Z:#]____
M)3J4(`!H)0```.F0_?___R4RE"``:"8```#I@/W___\E*I0@`&@G````Z7#]
M____)2*4(`!H*````.E@_?___R4:E"``:"D```#I4/W___\E$I0@`&@J````
MZ4#]____)0J4(`!H*P```.DP_?___R4"E"``:"P```#I(/W___\E^I,@`&@M
M````Z1#]____)?*3(`!H+@```.D`_?___R7JDR``:"\```#I\/S___\EXI,@
M`&@P````Z>#\____)=J3(`!H,0```.G0_/___R72DR``:#(```#IP/S___\E
MRI,@`&@S````Z;#\____)<*3(`!H-````.F@_/___R6ZDR``:#4```#ID/S_
M__\ELI,@`&@V````Z8#\____):J3(`!H-P```.EP_/___R6BDR``:#@```#I
M8/S___\EFI,@`&@Y````Z5#\____)9*3(`!H.@```.E`_/___R6*DR``:#L`
M``#I,/S___\E,I$@`&:0_R4ZD2``9I#_)5*1(`!FD/\E4I$@`&:02(/D\$B#
M[`A(B==(B=[IP@$``&8N#Q^$```````/'P!54TB#[`A(C1W[CB``2(T%](X@
M`$@YPW,;2(U3`4@IT$C!Z`-(C6S#"/\32(/#"$@YZW7U2(/$"%M=PT%455-(
MC1V2^___3(TEB_O__TPYXW,9@WL()7482(LK_U,02(E%`$B#PQA,.>-RYUM=
M05S#Z*O[__](8])(8_9(C40R`DB-%,>+`H7`#X3D````OO____\QR>L<@_@'
M#X3&````@_@#=01(BTH(2(/"$(L"A<!T$X/X!77?#[=R"$B#PA"+`H7`=>U(
MA<D/A*,```!F@_[_#X29````#[?&2&O`.$@!R$@YR`^&A@```+[_____,?_K
M%8/Z!G4'2(G.2"MQ$$B#P3A(.<AV$XL1@_H"=>1(B<](@\$X2#G(=^U(A?]T
M4+C_____2#G&=$9(BT\02`'Q2(L12(72=#<Q_S'`ZQ9(@_H(=01(BWD(2(/!
M$$B+$4B%TG0<2(/Z!W7D2(M!"$@!\.OE2(-Z"``/A#C____#PTB-##A(.<%F
M#Q]$``!W$>ON2(/Z)74B2(/`&$@YP7;?BU`(2(/Z"'7H2(L02(MX$$@!]TB)
M/#+KWDB#[`CH:_K__T%505154TB#[`A(B?M(B?6+5AB+=@A(BWT`Z*'^__](
MC07UD2``2(DH3(TE*Y(@`$B+11!)B00D2(M%`$B+$$B%T@^$UP```$B-#421
M(`!(B1%(BP`/MA"$TG032(/``8#Z+W7P2(D!#[80A-)U[4B%VW0(2(G?Z(_\
M___HVOS__TB#/<*.(```#X2F````2(T=O8P@`$B-!;:,(`!(.<-S&TB-4P%(
M*=!(P>@#3(ULPPC_$TB#PPA,.>MU]4B-/8?]___H0OS__TB-'8.,(`!(C05\
MC"``2#G#<QM(C5,!2"G02,'H`TR-;,,(_Q-(@\,(3#GK=?5(C3U--0``Z`C\
M___H(_G__XM]"$F+%"1(BW4`Z"$S``")Q^A<^___2(T%;9`@`$B-#?:0(`!(
MB0CI.O___^A,_?__Z5#___^`/9Z0(```=`'#4\8%DY`@``%(@ST:CB```'0,
M2(L].9`@`.BT_/__2(T=_8L@`$B+`TB%P'0(_]!(@\,(Z_!(@SV]C2```'0,
M2(T]/'<``.AW_/__6\.`/4:0(```=`'#4\8%.Y`@``%(@SW+C2```'032(TU
MZH\@`$B-/0MW``#H7OS__TB#/8:-(```=!)(C3V=BR``2(,_`'0%Z#+\__](
MC1UKBR``2(L#2(/X_W0(_]!(@^L(Z^];PT%7059!54%455-(@^P(2(7_#X28
M````2(T%0I`@`$R+.$V%_P^$A0````^V!X3`=`0\/75/13'D28L?2(7;=#))
MB?5)B?Y-8^1,B?U,B>),B?9(B=_H%OG__X7`=0="@#PC/70X2(/%"$B+70!(
MA=MUVDB)V$B#Q`A;74%<05U!7D%?PTF)_$F#Q`%!#[8$)(3`=`0\/77O02G\
MZYM,*?U(P?T#08EM`$J-7",!Z\,QV^N_05154TB#[!!(B?U,BR6KC"``28L$
M)$B)1"0(,<!(C5PD!$B)WDB)[S'`Z![___](A<!T,4AC5"0$2(T%;8\@`$B+
M`$B-!-!(BU`(2(D02(72=,](@\`(2(M0"$B)$$B%TG7PZ[U(BT0D"$DS!"1U
M"4B#Q!!;74%<P^BO^O__05=!5D%505154TB![+@```!(BQTGC"``2(L#2(F$
M)*@````QP$B%_W0(28G_@#\`=2-(BX0DJ````$@S`P^%`P$``$B!Q+@```!;
M74%<05U!7D%?P^AU^O__2(G%2(7`=-!,C27',@``2(U$)!!(B40D"$B)[^CD
M^?__2(7`#X2E````3(UH#;D"````3(GN3(GG\Z8/E\`<`(3`=-6Y`P```$R)
M[DB-/8(R``#SI@^7P!P`A,!TNTR)_^C?^?__28G&3(GOZ-3Y__]!C7P&`DAC
M_^A']___28G&3(GI3(GZ2(TU2C(``$B)QS'`Z'WY__](BW0D"$R)]^@0]___
M3(GW@_C_=!"+1"08)0#P```]`$```'0GZ./V__],B??HV_C__^E*____2(GO
MZ#[W__],B?_H=OC__^GT_O__D.B\_O__Z];H9/G__T%7059!54%455-(@^PX
M2(G]28GU2(L=V8H@`$B+`TB)1"0H,<"`/CUU!$F#Q0%,B>_H'OG__TF)Q$B-
M="0D2(GO,<#H//W__TF)QDB%P`^$Z@```$B)Q^CX^/__3#G@#X/"````3&-\
M)"1)P><#3(TU;XT@``^V10"$P`^$CP$``#P]#X2'`0``2(GHZPB`^CT/'P!T
M"TB#P`$/MA"$TG7M2"GH2)A-`SY*C7P@`N@A]O__28D'2(7`#X1D`0``2&-4
M)"1)BP9(BQ302(U-`0^V10"(`H3`=13K%DB#P@%(@\$!#[9!_X@"A,!T!#P]
M=>K&`CTQP$$/MDP%`(A,`@%(@\`!A,EU[C'`2(MT)"A(,S,/A14!``!(@\0X
M6UU!7$%=05Y!7\-)@\4!28/&`4$/MD7_08A&_X3`=>OKRDR--9^,(`!-BP9)
M@S@`#X3%````3(G`,=+K`HG*2(/`"(U*`4B#.`!U\8UR`TAC]DC!Y@.+!3R,
M(`"%P(E,)`AU:TR)1"08QP4EC"```0```$B)]^@]]?__2(7`#X2#````3&-4
M)`A$B50D%$Z-/-4`````3(E4)`A,B?I,BT0D&$R)QDB)Q^@:]?__28G!28D&
MBTPD%$R+5"0(2\=$T0@`````B4PD).F*_O__3(G'Z!'T__])B<%)B09(A<!T
M)4QC5"0(3(G13HT\U0````#KR3'`Z8_^__^^$````#')Z4____^X_____^G=
M_O__Z#+W__]54TB![*@```!(B?U(BQVOB"``2(L#2(F$))@````QP$B)YNAZ
M]O__A<!U2(M4)`B!X@#P``"!^@!```!T'X'Z`*```'072(N,))@```!(,PMU
M)4B!Q*@```!;7<.^`@```$B)[^B8\___A<`/E,`/ML#KTC'`Z\[HM?;__T%7
M059!54%455-(@>PH!```28G^28GW2(L%)X@@`$B+"$B)C"08!```,<E(C5PD
M$+K_`P``2(G>2(T]_RX``.CA]/__A<`/CHX```!)B<2-4/^)5"0,9$B+!"4`
M````2`,%SX<@`$B+*$QC;"0,0H!\+!``=$]-8^Q,B>J^+P```$B)W^B,]?__
M2(7`=#Q,B>E(B=I,B?9(B>_HUO+__TB+!9^'(`!(BXPD&`0``$@S"'5*2('$
M*`0``%M=05Q!74%>05_#187M=:],B?I,B?9(B>_H+?3__^O%9$B+!"4`````
M2`,%2X<@`$B+*$R)^DR)]DB)[^@*]/__ZZ+HL_7__U532('L&`0``$B)_DB+
M+3"'(`!(BT4`2(F$)`@$```QP$B)X[H`!```2(G?Z!+T__](@^@!2#G8=P[K
M$<8``$B#Z`%(.=AT!8`X+W3OOB\```!(B=_H^?+__TB%P'0J2#G8=R!(B=_H
M%_/__TB+C"0(!```2#--`'4R2('$&`0``%M=P\8``.O;2(N$)`@$``!(,T4`
M=15(C3V6+0``2('$&`0``%M=Z=?R___H`O7__TB#[`AD2(L$)0````!(`P5N
MAB``2(T-QVT``$B+%8B&(`!(C35T+0``2(LX2(/$".E=]/__4V1(BP0E````
M`$@#!3R&(`!(B<-(BSCHK____T4QR4R-!=PN``!,B<%(C16/#0``2(TU32T`
M`$B+.UOI;?'__S'`PT%7059!54%455-(@>S8!```2(G[28GT2(L%_(4@`$B+
M$$B)E"3(!```,=)(C70D'$B-/1\M```QP.AL^/__2(G%OB\```!(B=_H?/+_
M_TB%P'0^2(G>2(T]`BT``#'`Z,+Z__](B=A(BQ6LA2``2(N,),@$``!(,PH/
MA7H!``!(@<38!```6UU!7$%=05Y!7\-,B>?HP?'__TB--<PL``!(B<?H@O/_
M_TF)Q4B%P'2C3(VD),````!,C70D($&`?0``#X33````2(7M=!-,B>Y(B>_H
MTO#__X7`#X26````3(GOZ)+S__])B<=)C40%_TDYQ7,C@#@O=`?K'(`X+W4,
MQ@``2(/H`4DYQ77O3(GOZ&7S__])B<=(B=_H6O/__TF-1`<!2#W_`P``#X<B
M____2(D<)$R-#14M``!-B>A(C0TN+0``N@`$```Q]DR)YS'`Z'/R__],B?9,
MB>?HB/#__X7`=1"+1"0H)0#P```]`(```'162(TU[RL``#'_Z*;R__])B<5(
MA<`/A,/^__]!@'T```^%+?___TB%[70:N0(```!(B>Y(C3U<*P``\Z8/E\`<
M`(3`=+Q!OP$```!,C2U$*P``Z4S___^^`0```$R)Y^B![___A<!UF4R)YDB-
M/7@K``#H.OG__TR)Y^AF\/__Z6[^__^0Z(OR__]32(G[OB\```#H'?#__TB%
MP'0$2(U8`4B)WUOI._#__TB%_W0C@#\`=!Y32(G[Z$CR__](@\`!2#T`!```
M=Q5(B=];Z9#\__](C3V]*@``Z0?P__\QP%O#55-(@^P82(LMMH,@`$B+10!(
MB40D"#'`2(T]^"H``.CB]O__2(T]]2H``#'`Z-3V__](C3WO*@``,<#HQO;_
M_TB-/>HJ```QP.BX]O__2(T]XRH``#'`Z*KV__](C3WE*@``,<#HG/;__TB-
M/8XJ```QP.B.]O__2(T]U2H``#'`Z(#V__](C3W1*@``,<#H<O;__TB-/<TJ
M```QP.AD]O__2(T]7RH``#'`Z%;V__](C5PD!$B)WDB-/;,J```QP.B-]?__
M2(7`=!%(B<9(C3V)*@``,<#H\_?__TB)WDB-/9TJ```QP.AF]?__2(7`=!%(
MB<9(C3V9*@``,<#HS/?__TB)WDB-/9,J```QP.@_]?__2(7`=#A(B<9(C3W<
M*0``,<#HI??__TB--5@K``!(C3T`*@``,<#HD/?__TB+1"0(2#-%`'4P2(/$
M&%M=PTB)WDB-/54J```QP.CQ]/__2(7`=,-(B<9(C3WC*0``,<#H5_?__^NP
MZ+3P__]32(/L$$B+'3B"(`!(BP-(B40D"#'`2(UT)`1(C3VS*0``Z*WT__](
MA<!T$0^V`(3`=`H\,`^5P`^VP.L",<!(BU0D"$@S$W4&2(/$$%O#Z&#P__](
M@>S8````2(ET)"A(B50D,$B)3"0X3(E$)$!,B4PD2(3`=#</*40D4`\I3"1@
M#RE4)'`/*9PD@`````\II"20````#RFL)*`````/*;0DL`````\IO"3`````
M2(L%CH$@`$B+"$B)3"08,<G'!"0(````QT0D!#````!(C80DX````$B)1"0(
M2(U$)"!(B40D$$B)XDB)_DB+!4F!(`!(C;@P`0``Z,7M__^__P```.A+[O__
M059!54%455-(@>P0``$`08G\3(LM(H$@`$F+10!(B80D"``!`#'`N@(````Q
M]NAX[/__2(UH_TBZ__\``````(!((>IY#TB#Z@%(@<H``/__2(/"`4@IU0^(
MJ0```$B)XTR--=$H```QTDB)[D2)Y^@V[/__2(/X_P^$D0```+H(``$`2(G>
M1(GGZ/SM__](8]"#^/]T3DB#^@=V5DB-1!/X2#G8<DQ(C14-@R``ZPE(@^@!
M2#G8<CI(BPI(.0AU[T@IW4@!Z$B+M"0(``$`23-U`'5*2('$$``!`%M=05Q!
M74%>PTB-/5HH```QP.A8_O__2('M```!`$B!_0``__\/A6'___](Q\#_____
MZ[=,B?<QP.@Q_O__Z6#____HA^[__TB#[`CHCN[__XG'Z&?L__](A<!T"$B+
M`$B#Q`C#,<#K]T%505154TB#[!A)B?Q(BRWB?R``2(M%`$B)1"0(,<!(C70D
M!$B-/>(G``#H5O+__TR)YDB%P'162(G#@#@`=$Y(B<?H'NS__TB%P'5/3(GG
MZ`'N__])B<5(B=_H]NW__TF-?`4"Z&SK__])B<5)B=A(C0W1)@``3(GB2(TU
MSR<``$B)QS'`Z)OM__],B>Y(C3UX)P``,<#H9O3__TB+1"0(2#-%`'4+2(/$
M&%M=05Q!7</HK^W__T%7059!54%455-(@>R(`0``28G^2(L%)'\@`$B+"$B)
MC"1X`0``,<E(C05#)P``2(E$)#!(C07U)0``2(E$)#A(QT0D0`````!(C07!
M)@``2(E$)'!(C06N)@``2(E$)'A(C040)P``2(F$)(````!(C06P)@``2(F$
M)(@```!(C07Z)@``2(F$))````!(QX0DF`````````!(C07%)@``2(E$)%!(
MC077)@``2(E$)%A(QT0D8`````!(C6PD+$B)[DB-/;$E```QP.C^\/__2(7`
M=`F`.``/A2`"```QP.A"_O__28G$2(7`#X17`@``3(GGZ*7L__](C7P``>@;
MZO__2(G#08`\)`!T*TF)W4R-/74F``!!#[84)$R)_DR)[S'`Z$7L__])@\0!
M28/%`D&`/"0`==],C60D<$B-/<PE``#K$4F#Q`A)BSPD2(7_#X18`0``2(GN
M,<#H;?#__TF)QTB%P'3=@#@`=-A(B<?H!O7__X7`=,Q,B?_H_.G__TB)PDB%
MP`^$(0$``$B)T8LQ2(/!!(V&__[^_O?6(?`E@("`@'3IB<;![A"I@(````]$
MQDB-<0)(#T3.B<9``,9(@]D#2"G12(G>BSY(@\8$C8?__O[^]]<A^"6`@("`
M=.E(B50D&(G'P>\0J8"````/1,=(C7X"2`]$]XG"`,)(@]X#2"G>1(V\,00$
M``!-8_],B?_H`^G__TF)Q$F)V4R-!6DE``!(C0U&)0``2(M4)!A(C35;)0``
M2(G',<#H*>O__[[``0``3(GGZ&SJ__^#^/\/A$X!``!(C;0DH````$R)Y^BS
MZO__B<.%P'47BX0DJ````"4`\```/0!````/A&@!``!,B>%)BQ9(C36Y)0``
M2(L%FGP@`$B-N#`!```QP.BTZ?__13'_ZVQ%,?])8\=,BV3$,$V%Y'0X08`\
M)`!T,4R)Y^BN\___08/'`87`=-Q,B>?HH.C__TB)PDB%P`^%I/[__TECQTR+
M9,0P387D=<@QTNF0_O__2(G'2(E$)!CH/?S__TB+1"082(G'Z&;H__])B<=,
MB?A(BPT9?"``2(N<)'@!``!(,QD/A64#``!(@<2(`0``6UU!7$%=05Y!7\-(
MC3T6)```,=M(A?]T)$B)[C'`Z&[N__^#PP%(A<!T!8`X`'4F2&/#2(M\Q%!(
MA?]UW+\-````Z)KG__](B<-,C27<(P``Z7K]__](B<?HX^?__TF)Q$B%P`^%
M2OW__^O$#Q]$``#H:^;__X,X$0^$G_[__V:0Z%OF__]$BP!,B>%)BQ9(C34[
M)```2(L%7'L@`$B-N#`!```QP.AVZ/__13'_Z2O___^+A"2\````08G%Z+_I
M__]!.<4/A8#^__^+A"2H````)?\!```]P`$```^%:?[__TR)_^CWYO__28G'
M2(GN2(T]+",``#'`Z)/M__](A<`/A#,!``!(B<9)BS[HU?3__TB)Q4B%P`^$
M'`$``$B)[^@[Z?__@_@#?CE(8]!(C705_+D%````2(T](R,``/.F#Y?"@-H`
MA-)U&8/X!`^$R`$``(/H!$B8@'P%_R\/A+@!```QP.A2^/__A<!U%#'V2(GO
MZ-CF__^)Q87`#X6_````2(TU/2,``$B-/0$B```QP.AU[___Z.3E__]!B<!,
MC0W_(@``2(T-BB(``$R)XDB--<XB``!,B?\QP.AOZ/__2(TMW2(``.LWZ!'E
M__^#.!%U/X/#`>BDY?__08G`2(DL)$&)V4B-#4HB``!,B>)(C36<(@``3(G_
M,<#H+^C__[[``0``3(G_Z'+G__^#^/]TMTR)Y^BEY___3(G^2(T]%R$``#'`
MZ.#N__],B?_HUOG__^FD_?__28LNZ=S^__^)Q^A]^/__28G&2(7`#X@N____
M2(UP]C'2B>_H#^7__TB-M"0Z`0``N@8```")[^C;YO__2(/X!G0.2(T]Z2$`
M`#'`Z(?W__^+!;E@```YA"0Z`0``#X7F_O__#[<%J6```&8YA"0^`0``#X71
M_O__28UVSC'2B>_HLN3__TB-G"1``0``NB@```!(B=Z)[^A[YO__2(/X*'0.
M2(T]B2$``#'`Z"?W___&A"1H`0```$R-#:TA``!)B=A(C0TU(0``3(GB2(TU
M:B$``$R)_S'`Z!KG___I^/[__TV+=@A-A?8/A#O^__],B??H,.?__TB#^`,/
MABG^__])C70&_+D%````2(T]&R$``/.F#Y?`'`"$P$D/1.[I!O[__^@.Y___
M055!5%532(/L&$R+)8UX(`!)BP0D2(E$)`@QP&1(BP0E`````$@#!6)X(`!(
MBP`/MI"P````B)"Q````2(UL)`1(B>Y(C3W('P``,<#HW.K__TB%P'0)@#@Q
M#X1\`0``,<#H=/3__V1(BP0E`````$@#!1=X(`!)B<6Y`P```+H!````2(TU
MMR```$B+..BKY/__2(G#2(7`="A(BT`02(T5GB```$B+,$F+?0#HK.3__TB+
M0Q!(BS#V1@Y`#X5#`0``9$B+!"4`````2`,%NW<@`$F)Q;D#````N@$```!(
MC35B(```2(LXZ$_D__](B<-(A<!T+4B)[DB-/>(>```QP.@FZO__2(7`#X3:
M````2(M+$$B)PDB+,4F+?0#H.N3__V1(BP0E`````$@#!5IW(`!(B<.Z`0``
M`$B--0@@``!(BSCH<^+__TB-%0X@``!(B<9(BSOH`>3__TB+`\:`L0````!(
MB>Y(C3UI'@``,<#HMNG__TB)!>=Y(`!(A<!T-+[``0``2(G'Z(WD__^#^!%T
M"(U0`8/Z`7=V2(M$)`A),P0D#X6(````2(/$&%M=05Q!7<-(BSVO>2``Z)OW
M__](B06;>2``2(7`=;1(C3TO(```Z"+B__^`>`$`#X2!_O__Z77^__](BT,0
M2(L5>'D@`$B+,DB+..A8[O__Z1[___])BWT`Z#_B___IK_[__XG!2(L527D@
M`$B+!4IY(`!(BS!(C3T`(```,<#HR>'__^C4Y/__4TB)^S'`Z!7T__^%P'0*
M2(7;=`6`.P!U`EO#2(G?Z$;R__](B<?H'O+__[D$````2(T]@!X``$B)QO.F
M#Y?`'`"$P'742(G?6^G7Z?__9@\?1```05=!5D%505154TB![)@"``!(BP7X
M=2``2(L82(F<)(@"```QVTR-3SA%,<!(B>%#BP0!#\A+BS0!B<!*B01!2(GR
M2,'J($B)\$C!Z"@E`/\``$C![CA("?!(B=9(P>88B?9("?!(P>((@>(``/\`
M2`G02HE$00A)@\`(28/X0'6N2(VQ``(``$B+06A(,T%`2#-!$$@S`4B-%`!(
MP>@?2`G0@^#_2(F!@````$B#P0A(.?%UTTR+%TR+3PA(BU\02(MO&$R)T$C!
MX`5,B=)(P>H;2`G0`P0D2(MW((V4,)EY@EI(B=A(,>A,(<A(,>A$C20"3(G)
M2,'A'DR)R$C!Z`)("<%!B<A(B=A,,<!,(=!(,=A(BU0D"$B-E!69>8):2`'0
M3(GB2,'B!4R)YDC![AM("?)$C1P"3(G22,'B'DR)T$C!Z`)("<*)UD@QT4PA
MX4PQP4B+1"002(V$`YEY@EI(`<%,B=A(P>`%38G=2<'M&TP)Z$2-+`A,B>!(
MP>`>2<'L`DP)X(G!2#'"3"':2#'R3(MD)!A/C80@F7F"6DP!PDV)Z$G!X`5-
MB>Q)P>P;30G@18TD$$V)V$G!X!Y)P>L"30G81(G"3#'`3"'H2#'(3(M<)"!*
MC;0>F7F"6D@!\$R)YDC!Y@5-B>-)P>L;3`G>1(T<!DR)[DC!YAY)P>T"3`GN
MB?!),?!-(>!),=!,BVPD*$J-C"F9>8):3`'!38G82<'@!4V)W4G![1M-">A%
MC2P(3(GA2,'A'DG![`),">%!B<A(,<Y,(=Y(,<9,BV0D,$J-E"*9>8):2`'R
M3(GN2,'F!4V)[$G![!M,">9$C2063(G:2,'B'DG!ZP),"=J)UD@QT4PAZ4PQ
MP4R+7"0X2HV$&)EY@EI(`<A,B>%(P>$%38GC2<'K&TP)V42-'`%,B>A(P>`>
M2<'M`DP)Z(G!2#'"3"'B2#'R3(ML)$!/C80HF7F"6DP!PDV)V$G!X`5-B=U)
MP>T;30GH18TL$$V)X$G!X!Y)P>P"30G@1(G"3#'`3"'82#'(3(MD)$A*C;0F
MF7F"6D@!\$R)[DC!Y@5-B>Q)P>P;3`GF1(TD!DR)WDC!YAY)P>L"3`G>B?!)
M,?!-(>A),=!,BUPD4$J-C!F9>8):3`'!38G@2<'@!4V)XTG!ZQM-"=A%C1P(
M3(GI2,'A'DG![0),">E!B<A(,<Y,(>9(,<9,BVPD6$J-E"J9>8):2`'R3(G>
M2,'F!4V)W4G![1M,">Y$C2P63(GB2,'B'DG![`),">*)UD@QT4PAV4PQP4R+
M9"1@2HV$()EY@EI(`<A,B>E(P>$%38GL2<'L&TP)X42-)`%,B=A(P>`>2<'K
M`DP)V(G!2#'"3"'J2#'R3(M<)&A/C808F7F"6DP!PDV)X$G!X`5-B>-)P>L;
M30G818T<$$V)Z$G!X!Y)P>T"30GH1(G"3#'`3"'@2#'(3(ML)'!*C;0NF7F"
M6D@!\$R)WDC!Y@5-B=U)P>T;3`GN1(TT!DR)YDC!YAY)P>P"3`GFB?!),?!-
M(=A),=!,BV0D>$J-C"&9>8):3`'!38GP2<'@!4V)]$G![!M-">!%C20(3(G9
M2,'A'DG!ZP),"=E!B<M(,<Y,(?9(,<9,BX0D@````$J-E`*9>8):2`'R3(GF
M2,'F!4V)X$G!Z!M,"<9$C2P63(GR2,'B'DG![@),"?*)UD@QT4PAX4PQV4R+
MA"2(````2HV$`)EY@EI(`<A,B>E(P>$%38GH2<'H&TP)P42-!`%,B>!(P>`>
M2<'L`DP)X(G!2#'"3"'J2#'R3(ND))````!/C9PCF7F"6DP!VDV)PTG!XP5-
MB<1)P>P;30GC18G;3`':08G438GK2<'C'DG![0)-">M,,=A,(<!(,<A,BZPD
MF````$J-M"Z9>8):2`'P3(GF2,'F!4V)Y4G![1M,">Z)]D@!\$&)QDR)QDC!
MYAY)P>@"3`G&38G=23'U1#'J3(N$)*````!*C8P!H>O9;D@!T4R)\DC!X@5-
MB?5)P>T;3`GJB=),C2P11(GI38G@2<'@'DG![`)-">!$B=I(`Y0DJ````$F)
M\TTQPT0QV$B-E`*AZ]EN2(G(2,'@!4F)S$G![!M,">")P$R-)`)%B>-,B?)(
MP>(>2<'N`DP)\HGP2`.$)+````!,B<9(,=9!,?5*C;0HH>O9;DR)V$C!X`5-
MB=U)P>T;3`GHB<!(`?!!B<5(B<Y(P>8>2,'I`D@)SD2)P4@#C"2X````28G0
M23'P13'$3HVD(:'KV6Y,B>E(P>$%38GH2<'H&TP)P8G)38T$#$6)Q$R)V4C!
MX1Y)P>L"3`G9B=)(`Y0DP````$F)\TDQRT0QV$B-E`*AZ]EN3(G@2,'@!4V)
MXTG!ZQM,"=B)P$R-'`)%B=Y,B>A(P>`>2<'M`DP)Z(GR2`.4),@```!(B<Y(
M,<9!,?!*C;0"H>O9;DR)\DC!X@5-B?!)P>@;3`G"B=),C00618G%3(GB2,'B
M'DG![`),">*)R4@#C"30````2(G&2#'603'S2HVT&:'KV6Y,B>E(P>$%38GK
M2<'K&TP)V8G)3(T<#D6)W$R)]DC!YAY)P>X"3`GVB<!(`X0DV````$B)T4@Q
M\4$QR$J-C`"AZ]EN3(G@2,'@!4V)X$G!Z!M,"<")P$R-!`%%B<9,B>E(P>$>
M2<'M`DP)Z8G02`.$).````!(B?)(,<I!,=-*C908H>O9;DR)\$C!X`5-B?-)
MP>L;3`G8B<!,C1P"18G=3(G@2,'@'DG![`),">")\D@#E"3H````2(G.2#'&
M03'P2HVT`J'KV6Y,B>I(P>(%38GH2<'H&TP)PHG23(T$%D6)Q$R)\DC!XAY)
MP>X"3`GRB<E(`XPD\````$B)QD@QUD$Q\TJ-M!FAZ]EN3(GA2,'A!4V)XTG!
MZQM,"=F)R4R-'`Y%B=Y,B>Y(P>8>2<'M`DP)[HG`2`.$)/@```!(B=%(,?%!
M,<A*C8P`H>O9;DR)\$C!X`5-B?!)P>@;3`G`B<!,C00!18G%3(GA2,'A'DG!
M[`),">&)T$@#A"0``0``2(GR2#'*03'32HV4&*'KV6Y,B>A(P>`%38GL2<'L
M&TP)X(G`3(TD`D6)XTR)\$C!X!Y)P>X"3`GPB?)(`Y0D"`$``$B)SD@QQD$Q
M\$J-M`*AZ]EN3(G:2,'B!4V)V$G!Z!M,"<*)TDR-!!9%B<9,B>I(P>(>2<'M
M`DP)ZHG)2`.,)!`!``!(B<9(,=9!,?1*C;0AH>O9;DR)\4C!X05-B?5)P>T;
M3`GIB<E,C2P.18GL3(G>2,'F'DG!ZP),"=Z)P$@#A"08`0``2(G12#'Q03'(
M2HV,`*'KV6Y,B>!(P>`%38G@2<'H&TP)P(G`3(T$`46)PTR)\4C!X1Y)P>X"
M3`GQB=!(`X0D(`$``$B)\D@QRD$QU4Z-K"BAZ]EN3(G82,'@!4R)VDC!ZAM(
M"=")P$F-5`4`08G63(G@2,'@'DG![`),">")]D@#M"0H`0``28G,23'$13'@
M3HVD!J'KV6Y,B?9(P>8%38GP2<'H&TP)QHGV38T$-$6)Q4V)W$G!Y!Y)P>L"
M30G<B<E(`XPD,`$``$B)QDPQYC'R2(V,$:'KV6Y,B>I(P>(%3(GN2,'N&T@)
M\D2-'`I,B?)(P>(>2<'N`DP)\HG6B<!(`X0D.`$``$R)X4@QT4$QR$J-C`"A
MZ]EN3(G82,'@!4V)V$G!Z!M,"<!$C30(38GH2<'@'DG![0)-">A$B<%,"<),
M(=I(B?!((<A("<*XW+P;CTR+K"1``0``20'%18GD30'L3`'B38GT2<'D!4V)
M]4G![1M-">Q!`=1,B=I(P>(>2<'K`DP)VD&)TTD)T$TA\$F)S4TAW4T)Z$R+
MK"1(`0``20'%3`'N3`'&38G@2<'@!4V)Y4G![1M-">A%C2PP3(GV2,'F'DG!
M[@),"?9!B?!("?),(>)-B=Y-(<9,"?),B[0D4`$``$D!QDP!\4@!RDR)Z4C!
MX05-B>Y)P>X;3`GQ1(TT$4R)X4C!X1Y)P>P"3`GAB<I("<Y,(>Y-B<1)(=1,
M">9,BZ0D6`$``$D!Q$T!XTP!WDV)\TG!XP5-B?1)P>P;30GC18TD,TV)ZTG!
MXQY)P>T"30GK1(G>3`G93"'Q28G522'U3`GI3(NL)&`!``!)`<5-`>A,`<%-
MB>!)P>`%38GE2<'M&TT)Z$6-+`A-B?!)P>`>2<'N`DT)\$2)P4T)PTTAXTF)
M]DDASDT)\TR+M"1H`0``20'&3`'R3`':38GK2<'C!4V)[DG![AM-"?-%C303
M3(GB2,'B'DG![`),">)!B=-)"=!-(>A)B<Q-(=Q-">!,BZ0D<`$``$D!Q$P!
MYDP!QDV)\$G!X`5-B?1)P>P;30G@18TD,$R)[DC!YAY)P>T"3`GN08GP2`GR
M3"'R38G=32'%3`GJ3(NL)'@!``!)`<5,`>E(`<I,B>%(P>$%38GE2<'M&TP)
MZ42-+!%,B?%(P>$>2<'N`DP)\8G*2`G.3"'F38G&22'63`GV3(NT)(`!``!)
M`<9-`?-,`=Y-B>M)P>,%38GN2<'N&TT)\T6--#--B>-)P>,>2<'L`DT)XT2)
MWDP)V4PAZ4F)U$DA]$P)X4R+I"2(`0``20'$30'@3`'!38GP2<'@!4V)]$G!
M[!M-">!%C20(38GH2<'@'DG![0)-">A$B<%-"<--(?-)B?5)(<U-">M,BZPD
MD`$``$D!Q4P!ZDP!VDV)XTG!XP5-B>5)P>T;30GK18TL$TR)\DC!XAY)P>X"
M3`GR08G320G032'@28G.32'>30GP3(NT))@!``!)`<9,`?9,`<9-B>A)P>`%
M38GN2<'N&TT)\$6--#!,B>9(P>8>2<'L`DP)YD&)\$@)\DPAZDV)W$TAQ$P)
MXDR+I"2@`0``20'$3`'A2`'*3(GQ2,'A!4V)]$G![!M,">%$C2013(GI2,'A
M'DG![0),">F)RD@)SDPA]DV)Q4DAU4P)[DR+K"2H`0``20'%30'K3`'>38GC
M2<'C!4V)Y4G![1M-">M%C2PS38GS2<'C'DG![@)-"?-$B=Y,"=E,(>%)B=9)
M(?9,"?%,B[0DL`$``$D!QDT!\$P!P4V)Z$G!X`5-B>Y)P>X;30GP18TT"$V)
MX$G!X!Y)P>P"30G@1(G!30G#32'K28GT22',30GC3(ND)+@!``!)`<1,`>),
M`=I-B?-)P>,%38GT2<'L&TT)XT6-)!-,B>I(P>(>2<'M`DP)ZD&)TTD)T$TA
M\$F)S4TAW4T)Z$R+K"3``0``20'%3`'N3`'&38G@2<'@!4V)Y4G![1M-">A%
MC2PP3(GV2,'F'DG![@),"?9!B?9("?),(>)-B=A-(?!,"<),BX0DR`$``$D!
MP$P!P4@!RDR)Z4C!X05-B>A)P>@;3`G!1(T$$4R)X4C!X1Y)P>P"3`GA08G,
M2`G.3"'N3(GR3"'B2`G62(N4)-`!``!(`<),`=I(`=9,B<)(P>(%38G#2<'K
M&TP)VHG22`'608GS3(GJ2,'B'DG![0),">I!B==("=%,(<%-B>5-(?U,">E(
M`X0DV`$``$P!\$@!R$R)V4C!X05-B=U)P>T;3`GIB<E(`<A!B<5,B<%(P>$>
M2<'H`DD)R$PQPC'6N=;!8LI(BY0DX`$``$@!RDP!XD@!\DR)[DC!Y@5-B>Q)
MP>P;3`GFB?9(`?*)UDV)W$G!Y!Y)P>L"30GC38G$33'<1#'@3(NT).@!``!)
M`<Y/C20^20'$2(GP2,'@!4F)]DG![AM,"?")P$D!Q$6)YDR)Z$C!X!Y)P>T"
M20G%2(N$)/`!``!(`<A%B<!,`<!-B=A-,>A$,<)(`<),B?!(P>`%38GP2<'H
M&TP)P(G`2`'"08G02(GP2,'@'DC![@)("<9(BX0D^`$``$@!R$6)VTP!V$V)
MZTDQ\T4QXTD!PTR)P$C!X`5-B<1)P>P;3`G@B<!)`<-%B=Q,B?!(P>`>2<'N
M`DP)\$R+M"0``@``20'.18GM30'U28GV23'&1#'R20'53(GB2,'B!4V)YDG!
M[AM,"?*)TDD!U46)[DR)PDC!XAY)P>@"20G02(N4)`@"``!(`<J)]D@!\DB)
MQDPQQD$Q\TD!TTR)\DC!X@5,B?9(P>X;2`GRB=))`=-%B=],B>9(P>8>2<'L
M`DP)YDB+E"00`@``2`'*B<!(`=!-B<1),?1%,>Q)`<1,B?A(P>`%3(GZ2,'J
M&T@)T(G`20'$18GE3(GP2,'@'DG![@))"<9(BX0D&`(``$@!R$6)P$P!P$F)
M\$TQ\$4QV$D!P$R)Z$C!X`5,B>I(P>H;2`G0B<!)`<!%B<-,B?I(P>(>2<'O
M`DP)^DB+A"0@`@``2`'(B?9(`?!,B?9(,=9!,?1)`<1,B=A(P>`%3(G>2,'N
M&T@)\(G`20'$18GG3(GH2,'@'DG![0))"<5(BX0D*`(``$@!R$6)]DP!\$B)
MUDPQ[D$Q\$D!P$R)^$C!X`5,B?Y(P>X;2`GPB<!)`<!%B<9,B=A(P>`>2<'K
M`DP)V$B+M"0P`@``2`'.B=)(`?)-B>M),<-%,>-)`=-,B?)(P>(%3(GV2,'N
M&T@)\HG220'318G<3(GZ2,'B'DG![P))"==(BY0D.`(``$@!RD6)[4P!ZDB)
MQDPQ_D$Q\$D!T$R)XDC!X@5,B>9(P>X;2`GRB=))`=!%B<5,B?9(P>8>2<'N
M`DP)]DB+E"1``@``2`'*B<!(`=!,B?I(,?)!,=-)`<-,B>A(P>`%3(GJ2,'J
M&T@)T(G`20'#18G>3(G@2,'@'DG![`))"<1(BX0D2`(``$@!R$6)_TP!^$B)
M\DPQXD$QT$D!P$R)\$C!X`5,B?)(P>H;2`G0B<!)`<!%B<=,B>I(P>(>2<'M
M`DP)ZDB+A"10`@``2`'(B?9(`?!,B>9(,=9$,=Y(`<9,B?A(P>`%38G[2<'K
M&TP)V(G`2`'&08GS3(GP2,'@'DG![@))"<9(BX0D6`(``$@!R$6)Y$P!X$F)
MU$TQ]$4QQ$D!Q$R)V$C!X`5-B=A)P>@;3`G`B<!)`<1%B>!,B?A(P>`>2<'O
M`DP)^$R+K"1@`@``20'-B=),`>I-B?5),<5$,>Y(`=9,B<)(P>(%38G%2<'M
M&TP)ZHG22`'608GU3(G:2,'B'DG!ZP))"=-(BY0D:`(``$@!RD6)]DP!\DF)
MQDTQWD4Q]$P!XDV)[$G!Y`5-B>Y)P>X;30GT18GD3`'B08G438G&2<'F'DG!
MZ`)-"?!,B[0D<`(``$D!SHG`3`'P38G>33'&1#'V2`'P3(GF2,'F!4V)YDG!
M[AM,"?8!QDR)Z$C!X!Y)P>T"20G%3(G@2,'@'DG![`))"<1(`XPD>`(``$2)
MV$@!P4R)P$PQZ#'"2(T$$4B)\DC!X@5(B?%(P>D;2`G*`=!!`<),B1=$`<Y(
MB7<(1`'C2(E?$$0![4B);QA$`T<@3(E'($B+!3Q@(`!(BYPDB`(``$@S&'42
M2('$F`(``%M=05Q!74%>05_#Z(C.__](@^P(OX````#HZLO__TC'``$C16>Z
MB:O-[TB)4`BY_MRZF$B)2!!(QT`8=E0R$+[PX=+#2(EP($C'0"@`````2,=`
M,`````#'0'@`````2(/$",-!5T%6055!5%532(/L"$F)_$B)\TACPDF)Q4B+
M=RB-#,9(BU<P2#GQ2(/2`$B)3RA(P>@=2`'02(E',$AC?WA)C6PD.(7_=%!!
MOT````!!*?]%.?U%#T[]36/W2`'O3(GR2(G>Z)O-__]!BT0D>$0!^$&)1"1X
M@_A`=`](@\0(6UU!7$%=05Y!7\-%*?U,`?-,B>?H'.G__T&#_3]^<$&#[4!%
MB>]!P>\&18G^28/&`4G!Y@9)`=Y(BP-(B44`2(M#"$B)10A(BT,02(E%$$B+
M0QA(B4482(M#($B)12!(BT,H2(E%*$B+0S!(B44P2(M#.$B)13A(@\-`3(GG
MZ++H__],.?-UL$'!YP9%*?U)8\5(B>](B=Y(@_@(<R2H!'0!I:@"=`)FI:@!
M=`&D18EL)'A(@\0(6UU!7$%=05Y!7\-`]L4!=5I`]L<"=2Y`]L<$=3Q(@_@(
M<L1(B<%(@^'X,=),BP063(D$%TB#P@A(.<IR[T@!UT@!UNNB#[<69HD72(/'
M`DB#Q@)(@^@"Z[Z+%HD72(/'!$B#Q@1(@^@$Z[(/MA-!B%0D.$B#QP%(@\8!
M2(/H`>N0059!54%455-(B?U(B?-,BV8H3(MV,$R)X$C!Z`.#X#],C6XXC5`!
M2)A!QD0%`(!(8_I,`>^#^C@/CK<!``"X0````"G0=`\QTHG1Q@0/`(/"`3G"
M<O-(B=_HG^?__TR)[[DX````,<!!]L4!#X5>`@``0/;'`@^%2@(``$#VQP0/
MA3<"``!!B<A!@^#@,=*)UDB)!#=(B40W"$B)1#<02(E$-QB#PB!$.<)RXT@!
MU_;!$'0$2*M(J_;!"'0"2*OVP01T`:OVP0)T`F:K@^$!#X53`0``3(GP2,'H
M&(A#<$R)\$C!Z!"(0W%,B?!(P>@(B$-R1(AS<TR)X$C!Z!B(0W1,B>!(P>@0
MB$-U3(G@2,'H"(A#=D2(8W=(B=_HW.;__TB+`TC!Z!B(10!(BP-(P>@0B$4!
M2(L#2,'H"(A%`DB+`XA%`TB+0PA(P>@8B$4$2(M#"$C!Z!"(105(BT,(2,'H
M"(A%!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$$C!Z`B(10I(
MBT,0B$4+2(M#&$C!Z!B(10Q(BT,82,'H$(A%#4B+0QA(P>@(B$4.2(M#&(A%
M#TB+0R!(P>@8B$402(M#($C!Z!"(11%(BT,@2,'H"(A%$DB+0R"(11-(B=];
M74%<05U!7NG8R?__N#@````IT(G",<"#^B!S+?;"$`^%B@```/;""'5\]L($
M=6KVP@)FD'56@^(!#X2M_O__J@\?0`#IH_[__T#VQP%U?$#VQP*0=6A`]L<$
M=6F#^B!RNT&)T$&#X.`QR8G.2(D$-TB)1#<(2(E$-Q!(B40W&(/!($0YP7+C
M2`'/ZY!FJX/B`0^$5?[__^NFJ_;"`G27#Q]$``#KYDBK]L($=(+KZDBK2*OV
MP@@/A&[____KZ&:K@^H"ZY&K@^H$ZY&J@^H!Z7O___^K@^D$Z<#]__]FJX/I
M`NFL_?__JKDW````Z9?]__]!5%532(/L,(E\)!Q(B70D$$B)5"0(2(L=%5L@
M`$B+`TB)1"0H,<!(C50D"$B-="002(U\)!SHY\?__TB+-1A;(`!(B?)(BST&
M6R``Z('&__](BP6J6B``@#@`=3?H8,?__TB)!:%=(`!(A<`/A(D!``!(B<?H
M&,C__V1(BP0E`````$@#!9A:(`!(BP#&@%X(````9$B+!"4`````2`,%?EH@
M`$B+`("(V@,```.+1"0<C6@#C7@$2&/_2,'G`^BNQ___2(D%-UT@`$B+?"00
M2(L72(D02(T-'0,``$B)2`A(C17:7"``2(L22(E0$$B-#0<#``!(B4@81(M$
M)!Q!@_@!#X[#````2(/'"$&#P`.^!````$B+#TACUDB)#-!(@\<(@\8!1#G&
M=>I(8_9(P>8#2,<$,`````!%,<!(B<&)ZDB--8O3__](BSVY7"``Z/S%__^%
MP'1D2(L]J5P@`.B<QO__08G$2(UL)"1(B>Y(C3T_`0``,<#H0\S__TB%P'0G
M2(L]?UP@`.CRQ___Z(W$__]$B>!(BTPD*$@S"W542(/$,%M=05S#2(L]2%P@
M`$B%_W0?Z!+C___KQDB+/45<(`#HF,;__^N.OB````#I7?___TB)[DB-/8X`
M``#HW<O__TB)QTB)!0M<(`!(A<!TD.O!Z*?'__^_`0```.@]QO__````````
M`````````$B#[`CHZ\K__TB#Q`C#```N+@`E<R\E<P`O<')O8R]C=7)P<F]C
M+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI0
M05(Z.D)/3U0`4$%27U1%35``4$%27U!23T=.04U%`#H`4$523#5,24(`4$52
M3$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?
M1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@!L<V5E:R!F86EL960`<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-`"]T;7`O`%1%35!$25(`
M5$U0`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`<VAO
M<G0@<F5A9``E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP
M+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-C$`
M+64`+2T````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````
M`1L#.Q`!```A````=(/__\0!``!$A___[`$``(2'__\L`0``OX?__U0!``#Y
MA___@`$``#F)__^8`0``-(O__P0"``#GB___4`(``&6,__^$`@``L(W__]`"
M``#BC___'`,``%^0__](`P``89'__Y0#```2DO__S`,``$>2___D`P``AY+_
M_P`$``"*DO__%`0``(F4__]@!```J93__WP$``#AE/__H`0``&"6___,!```
MM);___`$``!IE___"`4``(V8__]0!0``KIC__VP%``!EF?__J`4```:@___X
M!0``0*+__S0&``"4HO__C`8``(RX___<!@``X+C___0&``"7NO__6`<``'*]
M__]4!@``%``````````!>E(``7@0`1L,!PB0`0``)````!P```!0AO__.P``
M``!!#A"&`D$.&(,#1`X@<@X800X000X(`"@```!$````8X;__SH`````0@X0
MC`)!#AB&`T$.((,$;0H.&$$.$$(."$$+%````'````!QAO__0`$````#.P$.
M$```*````(@```"9A___/P$```!"#A"-`D(.&(P#00X@A@1!#BB#!40.,```
M```D````M````*B!___0`P````X01@X82@\+=PB``#\:.RHS)"(`````%```
M`-P```!0A?__(```````````````2````/0````HB?__LP````!"#A"/`D(.
M&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#D`":PH..$$.,$$.*$(.($(.&$(.
M$$(."$$+`#````!``0``CXG__WX`````0@X0C`)!#AB&`T$.((,$1`XP`FP*
M#B!!#AA!#A!"#@A!"P!(````=`$``-F)__]+`0```$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T<.\`%Y"@XX00XP00XH0@X@0@X80@X00@X(00L`
M2````,`!``#8BO__,@(```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX
M@P=$#G`##@$*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"R@````,`@``OHS__WT`
M````00X0A@)!#AB#`T<.P`$"40H.&$$.$$$."$$+2````#@"```/C?__`@$`
M``!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#N`(`JD*#CA!#C!!
M#BA"#B!"#AA"#A!"#@A!"S0```"$`@``Q8W__[$`````00X0A@)!#AB#`T<.
ML`@">`H.&$$.$$$."$$+80H.&$$.$$$."$4+%````+P"```^CO__-0````!$
M#A!L#@@`&````-0"``!;CO__0`````!!#A"#`GH."````!````#P`@``?X[_
M_P,`````````2`````0#``!NCO___P$```!"#A"/`D(.&(X#0@X@C01"#BB,
M!4$.,(8&00XX@P='#I`*`G4*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"Q@```!0
M`P``(9#__R``````00X0@P):#@@````@````;`,``"60__\X`````$L.$(,"
M6,,."%$.$(,"0PX(```H````D`,``#F0__]_`0```$$.$(8"00X8@P-$#C`#
M2`$*#AA!#A!!#@A!"R````"\`P``C)'__U0`````00X0@P)$#B`"2`H.$$$.
M"$$+`!0```#@`P``O)'__[4`````1P[@`0```$0```#X`P``69+__R0!````
M0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D<.P(`$`LT*#C!!#BA!#B!"#AA"
M#A!"#@A!"P```!@```!`!```-9/__R$`````1`X06`H."$$+```X````7`0`
M`#J3__^W`````$(.$(T"0@X8C`-!#B"&!$$.*(,%1`Y``J$*#BA!#B!!#AA"
M#A!"#@A!"P!,````F`0``+63__^A!@```$(.$(\"0@X8C@-"#B"-!$(.*(P%
M00XPA@9!#CB#!T<.P`,#+0,*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P```#@`
M``#H!```!IK__SH"````0@X0C0)"#AB,`T$.((8$00XH@P5$#D`#IP$*#BA!
M#B!!#AA"#A!"#@A!"QP````D!0``!)S__TX`````00X0@P)9"@X(00MN#@@`
M-````$0%```6M___!0(```!"#A",`D$.&(8#00X@@P1$#E`#G@$*#B!!#AA!
M#A!"#@A!"P````!,````?`4```"<___X%0```$(.$(\"0@X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!T<.T`4#UQ4*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P``
M`!0```#,!0``J+'__U0`````1`X0`D\."&````#D!0``Y+'__[<!````0@X0
MCP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``G$*#CA!#C!!#BA"#B!"
M#AA"#A!"#@A!"P*L"@XX00XP00XH0@X@0@X80@X00@X(00L\````2`8``#>S
M___;`@```$(.$(X"0@X8C0-"#B",!$$.*(8%00XP@P8#X0$*#BA!#B!"#AA"
M#A!"#@A%"P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````__________\``````````/__________````````````
M``````````$``````````0`````````!`````````,("`````````0``````
M``#,`@````````$`````````V@(````````!```````````#````````#P``
M``````!M!`````````P`````````D!H````````-`````````+!6````````
M!`````````!(`@````````4`````````R`X````````&`````````&@%````
M````"@````````"T!`````````L`````````&``````````5````````````
M`````````P``````````L"````````(`````````H`4````````4````````
M``<`````````%P````````#H%`````````<`````````@!,````````(````
M`````&@!````````"0`````````8`````````/O__V\`````````"`````#Y
M__]O``````0`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````X*T@````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#@K2````````````````````````````"V&@```````,8:
M````````UAH```````#F&@```````/8:````````!AL````````6&P``````
M`"8;````````-AL```````!&&P```````%8;````````9AL```````!V&P``
M`````(8;````````EAL```````"F&P```````+8;````````QAL```````#6
M&P```````.8;````````]AL````````&'````````!8<````````)AP`````
M```V'````````$8<````````5AP```````!F'````````'8<````````AAP`
M``````"6'````````*8<````````MAP```````#&'````````-8<````````
MYAP```````#V'`````````8=````````%AT````````F'0```````#8=````
M````1AT```````!6'0```````&8=````````=AT```````"&'0```````)8=
M````````IAT```````"V'0```````,8=````````UAT```````#F'0``````
M`/8=````````!AX````````6'@```````"8>````````-AX```````!&'@``
M`````%8>````````9AX```````"(LB````````"R(```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H``````````*A9````````1T-#
M.B`H3F5T0E-$(&YB-"`R,#(P,#@Q,"D@-RXU+C``1T-#.B`H;F(T(#(P,C`P
M.#$P*2`W+C4N,``D3F5T0E-$.B!C<G0P+E,L=B`Q+C0@,C`Q."\Q,2\R-B`Q
M-SHS-SHT-B!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G0P+6-O;6UO;BYC+'8@
M,2XR,R`R,#$X+S$R+S(X(#(P.C$R.C,U(&-H<FES=&]S($5X<"`D`"1.971"
M4T0Z(&-R=&DN4RQV(#$N,2`R,#$P+S`X+S`W(#$X.C`Q.C,U(&IO97)G($5X
M<"`D`"1.971"4T0Z(&-R=&)E9VEN+E,L=B`Q+C(@,C`Q,"\Q,2\S,"`Q.#HS
M-SHU.2!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G1E;F0N4RQV(#$N,2`R,#$P
M+S`X+S`W(#$X.C`Q.C,T(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=&XN4RQV
M(#$N,2`R,#$P+S`X+S`W(#$X.C`Q.C,U(&IO97)G($5X<"`D`/'/`@``````
M```````````(````"`````@````(````&P````$``````````"HJ*B!.;R!,
M86)E;"!0<F]V:61E9"`J*BH``/'/`@`````````````````(````"`````@`
M```(````&P````$``````````"HJ*B!.;R!,86)E;"!0<F]V:61E9"`J*BH`
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+FYE=&)S9"YI9&5N=``N;F]T92YN
M971B<V0N<&%X`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA
M;6EC`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`+E-53E=?8W1F````
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@```````````@`````````"
M````````%P````````````````````$````````````````````3````!P``
M``(`````````&`(````````8`@```````!@````````````````````$````
M````````````````)@````<````"`````````#`"````````,`(````````4
M````````````````````!````````````````````#<````%`````@``````
M``!(`@```````$@"````````'`,````````%``````````@`````````!```
M```````]````"P````(`````````:`4```````!H!0```````&`)````````
M!@````$````(`````````!@`````````10````,````"`````````,@.````
M````R`X```````"T!````````````````````0```````````````````$T`
M```$`````@````````"`$P```````(`3````````:`$````````%````````
M``@`````````&`````````!7````!````$(`````````Z!0```````#H%```
M`````*`%````````!0```!8````(`````````!@`````````80````$````&
M`````````)`:````````D!H````````.````````````````````$```````
M`````````````%P````!````!@````````"@&@```````*`:````````T`,`
M`````````````````!``````````$`````````!G`````0````8`````````
M<!X```````!P'@```````"`````````````````````(``````````@`````
M````<`````$````&`````````)`>````````D!X````````3.```````````
M````````$````````````````````'8````!````!@````````"P5@``````
M`+!6````````#@```````````````````!````````````````````!\````
M`0````(`````````P%8```````#`5@```````&I````````````````````(
M````````````````````A`````$````"`````````"R7````````+)<`````
M```4`0``````````````````!````````````````````)(````!`````@``
M``````!`F````````$"8````````C`8```````````````````@`````````
M``````````"<`````0````,`````````N*T@``````"XK0```````!``````
M```````````````(````````````````````HP````$````#`````````,BM
M(```````R*T````````0````````````````````"```````````````````
M`*H````!`````P````````#8K2```````-BM````````"```````````````
M``````@```````````````````"O````!@````,`````````X*T@``````#@
MK0```````,`!````````!@`````````(`````````!``````````:P````$`
M```#`````````*"O(```````H*\```````!@````````````````````"```
M```````(`````````+@````!`````P``````````L"````````"P````````
M^`$```````````````````@`````````"`````````#!`````0````,`````
M````^+$@``````#XL0```````'`````````````````````(````````````
M````````QP````@````#`````````("R(```````:+(```````!(````````
M````````````0````````````````````,P````!````,```````````````
M`````&BR````````.P````````````````````$``````````0`````````?
M`````0````````````````````````"CL@```````%4!````````````````
M```!````````````````````U0````$`````````````````````````^+,`
M``````"/````````````````````!`````````````````````$````#````
M`````````````````````(>T````````WP````````````````````$`````
+````````````````
